@@ -30,6 +30,7 @@ from lightdock.constants import (
 from lightdock.mathutil.ellipsoid import MinimumVolumeEllipsoid
 from lightdock.util.logger import LoggingManager
 from lightdock.error.lightdock_errors import LightDockError
+from lightdock.version import CURRENT_VERSION
 
 
 log = LoggingManager.get_logger("lightdock3_setup")
@@ -89,10 +90,10 @@ if __name__ == "__main__":
         if args.use_anm:
             if args.anm_rec > 0:
                 log.info("Calculating ANM for receptor molecule...")
-                calculate_anm(receptor, args.anm_rec, DEFAULT_REC_NM_FILE)
+                calculate_anm(receptor, args.anm_rec, args.anm_rec_rmsd, args.anm_seed, DEFAULT_REC_NM_FILE)
             if args.anm_lig > 0:
                 log.info("Calculating ANM for ligand molecule...")
-                calculate_anm(ligand, args.anm_lig, DEFAULT_LIG_NM_FILE)
+                calculate_anm(ligand, args.anm_lig, args.anm_lig_rmsd, args.anm_seed, DEFAULT_LIG_NM_FILE)
 
         # Parse restraints if any:
         receptor_restraints = ligand_restraints = None
@@ -158,6 +159,9 @@ if __name__ == "__main__":
             args.write_starting_positions,
             args.swarm_radius,
             args.flip,
+            args.fixed_distance,
+            args.swarms_per_restraint,
+            args.dense_sampling,
         )
         if len(starting_points_files) != args.swarms:
             args.swarms = len(starting_points_files)
@@ -166,6 +170,9 @@ if __name__ == "__main__":
         # Create simulation folders
         prepare_results_environment(args.swarms)
 
+        # Add manually setup version
+        args.setup_version = CURRENT_VERSION
+
         # Dump to a setup file the actual configuration
         create_setup_file(args)
 
