@@ -1,6 +1,7 @@
 """Module to prepare initial poses for docking"""
 
 import os
+import random
 import operator
 import numpy as np
 from lightdock.pdbutil.PDBIO import create_pdb_from_points
@@ -16,11 +17,21 @@ from lightdock.constants import (
     DEFAULT_BILD_STARTING_PREFIX,
     DEFAULT_EXTENT_MU,
     DEFAULT_EXTENT_SIGMA,
+    DEFAULT_SWARM_DISTANCE,
+    DEFAULT_SWARMS_PER_RESTRAINT,
 )
 from lightdock.prep.geometry import create_bild_file
 from lightdock.structure.residue import Residue
-from lightdock.error.lightdock_errors import LightDockWarning, MembraneSetupError
+from lightdock.error.lightdock_errors import (
+    LightDockWarning,
+    MembraneSetupError,
+    StructureError,
+)
 from scipy.spatial.transform import Rotation
+from lightdock.util.logger import LoggingManager
+
+
+log = LoggingManager.get_logger("lightdock3_setup")
 
 
 def get_random_point_within_sphere(number_generator, radius):
@@ -83,10 +94,21 @@ def get_quaternion_for_restraint(
     # Deal with possible DNA nucleotides
     if not r_ca:
         r_ca = rec_residue.get_atom("P")
+        if not r_ca:
+            # In case of HETATM
+            r_ca = rec_residue.get_central_atom()
+    if not r_ca:
+        raise StructureError(f"Cannot find a central atom for receptor restraint {rec_residue.full_name()}")
+
     l_ca = lig_residue.get_calpha()
     # Deal with possible DNA nucleotides
     if not l_ca:
         l_ca = lig_residue.get_atom("P")
+        if not l_ca:
+            # In case of HETATM
+            l_ca = lig_residue.get_central_atom()
+    if not l_ca:
+        raise StructureError(f"Cannot find a central atom for ligand restraint {lig_residue.full_name()}")
 
     # Center restraints pair at origin
     rx = r_ca.x + rt[0]
@@ -152,6 +174,11 @@ def populate_poses(
             ca = residue.get_calpha()
             if not ca:
                 ca = residue.get_atom("P")
+                if not ca:
+                    ca = residue.get_central_atom()
+                    if not ca:
+                        raise StructureError(f"Cannot find a central atom for residue {residue.full_name()}")
+
             distances.append(
                 (i, cdistance(ca.x, ca.y, ca.z, center[0], center[1], center[2]))
             )
@@ -256,10 +283,15 @@ def apply_restraints(
     blocking_restraints,
     distance_cutoff,
     translation,
-    swarms_per_restraint=10,
+    seed,
+    swarms_per_restraint=DEFAULT_SWARMS_PER_RESTRAINT,
 ):
     """Filter out swarm centers which are not close to the given restraints or too close
     to blocking residues"""
+    log.info(f"{len(swarm_centers)} swarm centers before applying restraints")
+    log.info("Applying restraints...")
+    log.info(f" * Distance cutoff: {distance_cutoff:.2f} Å")
+    log.info(f" * Swarms per restraint: {swarms_per_restraint}")
     closer_swarms = []
     for i, residue in enumerate(receptor_restraints):
         distances = {}
@@ -267,6 +299,11 @@ def apply_restraints(
         ca = residue.get_calpha()
         if not ca:
             ca = residue.get_atom("P")
+            if not ca:
+                ca = residue.get_central_atom()
+                if not ca:
+                    raise StructureError(f"Cannot find a central atom for residue {residue.full_name()}")
+
         # Calculate the euclidean distance between swarm center and given atom/bead
         for swarm_id, center in enumerate(swarm_centers):
             distances[swarm_id] = cdistance(
@@ -278,14 +315,16 @@ def apply_restraints(
                 center[2],
             )
         sorted_distances = sorted(list(distances.items()), key=operator.itemgetter(1))
-        swarms_considered = 0
-        for swarm in sorted_distances:
-            swarm_id, distance = swarm[0], swarm[1]
+
+        # Get swarms below the distance cutoff
+        swarms_considered = []
+        for swarm_id, distance in sorted_distances:
             if distance <= distance_cutoff:
-                closer_swarms.append(swarm_id)
-                swarms_considered += 1
-            if swarms_considered == swarms_per_restraint:
-                break
+                swarms_considered.append(swarm_id)
+
+        random.seed(seed)
+        swarms_considered = random.sample(swarms_considered, min(swarms_per_restraint, len(swarms_considered)))
+        closer_swarms.extend(swarms_considered)
 
     # Unique swarm ids
     closer_swarm_ids = sorted(list(set(closer_swarms)))
@@ -313,6 +352,12 @@ def apply_restraints(
             ca = residue.get_calpha()
             if not ca:
                 ca = residue.get_atom("P")
+                if not ca:
+                    # In case of HETATM
+                    ca = residue.get_central_atom()
+                    if not ca:
+                        raise StructureError(f"Cannot find a central atom for residue {residue.full_name()}")
+
             to_remove = []
             for center_id, center in enumerate(centers_list):
                 d = cdistance(
@@ -417,6 +462,9 @@ def calculate_initial_poses(
     writing_starting_positions=False,
     swarm_radius=10.0,
     flip=False,
+    swarms_at_fixed_distance=DEFAULT_SWARM_DISTANCE,
+    swarms_per_restraint=DEFAULT_SWARMS_PER_RESTRAINT,
+    dense_sampling=False
 ):
     """Calculates the starting points for each of the glowworms using the center of swarms"""
 
@@ -433,27 +481,39 @@ def calculate_initial_poses(
 
     # Calculate swarm centers
     has_membrane = is_membrane or is_transmembrane
+
+    blocking_restraints = []
+    # Filter swarms far from the restraints
+    if receptor_restraints:
+        blocking_restraints = receptor_restraints["blocked"]
+        receptor_restraints = receptor_restraints["active"] + receptor_restraints["passive"]
+
+
     swarm_centers, receptor_diameter, ligand_diameter = calculate_surface_points(
         receptor,
         ligand,
         num_swarms,
         rec_translation,
         surface_density,
+        receptor_restraints=receptor_restraints,
+        blocking_restraints=blocking_restraints,
         seed=seed,
         has_membrane=has_membrane,
+        swarms_at_fixed_distance=swarms_at_fixed_distance,
+        swarms_per_restraint=swarms_per_restraint,
+        dense_sampling=dense_sampling,
     )
+
     # Filter swarms far from the restraints
-    if receptor_restraints:
-        regular_restraints = (
-            receptor_restraints["active"] + receptor_restraints["passive"]
-        )
-        swarm_centers = apply_restraints(
-            swarm_centers,
-            regular_restraints,
-            receptor_restraints["blocked"],
-            ligand_diameter / 2.0,
-            rec_translation,
-        )
+    # if receptor_restraints:
+    #     swarm_centers = apply_restraints(
+    #         swarm_centers,
+    #         receptor_restraints,
+    #         blocking_restraints,
+    #         ligand_diameter / 2.0,
+    #         rec_translation,
+    #         seed=seed,
+    #     )
 
     # Filter out swarms which are not compatible with the explicit membrane
     if has_membrane:
