@@ -23,6 +23,8 @@ from lightdock.constants import (
     MAX_ROTATION,
     DEFAULT_SWARM_RADIUS,
     DEFAULT_MASK_FILE,
+    DEFAULT_SWARM_DISTANCE,
+    DEFAULT_SWARMS_PER_RESTRAINT,
 )
 from lightdock.util.logger import LoggingManager
 from lightdock.pdbutil.PDBIO import parse_complex_from_file, write_pdb_to_file
@@ -30,6 +32,7 @@ from lightdock.structure.complex import Complex
 from lightdock.structure.nm import calculate_nmodes, write_nmodes
 from lightdock.gso.boundaries import Boundary, BoundingBox
 from lightdock.error.lightdock_errors import LightDockError
+from lightdock.version import CURRENT_VERSION
 
 
 log = LoggingManager.get_logger("lightdock3_setup")
@@ -123,14 +126,14 @@ def save_lightdock_structure(structure):
     log.info("Done.")
 
 
-def calculate_anm(structure, num_nmodes, file_name):
+def calculate_anm(structure, num_nmodes, rmsd, seed, file_name):
     """Calculates ANM for representative structure"""
     original_file_name = structure.structure_file_names[structure.representative_id]
     # We have to use the parsed structure by LightDock
     parsed_lightdock_structure = Path(original_file_name).parent / Path(
         DEFAULT_LIGHTDOCK_PREFIX % Path(original_file_name).name
     )
-    modes = calculate_nmodes(parsed_lightdock_structure, num_nmodes, structure)
+    modes = calculate_nmodes(parsed_lightdock_structure, num_nmodes, rmsd, seed, structure)
     structure.n_modes = modes
     write_nmodes(modes, file_name)
     log.info(f"{num_nmodes} normal modes calculated")
@@ -170,12 +173,18 @@ def calculate_starting_positions(
     write_starting_positions=False,
     swarm_radius=DEFAULT_SWARM_RADIUS,
     flip=False,
+    swarms_at_fixed_distance=DEFAULT_SWARM_DISTANCE,
+    swarms_per_restraint=DEFAULT_SWARMS_PER_RESTRAINT,
+    dense_sampling=False
 ):
     """Defines the starting positions of each glowworm in the simulation.
 
     If the init folder already exists, uses the starting positions from this folder.
     """
     log.info("Calculating starting positions...")
+    log.info(f"  * Surface density: TotalSASA/{surface_density:.2f}")
+    log.info(f"  * Swarm radius: {swarm_radius:.2f} Å")
+    log.info(f"  * 180° flip of 50% of starting poses: {flip}")
     init_folder = DEFAULT_POSITIONS_FOLDER
     if not os.path.isdir(init_folder):
         os.mkdir(init_folder)
@@ -200,6 +209,9 @@ def calculate_starting_positions(
             write_starting_positions,
             swarm_radius,
             flip,
+            swarms_at_fixed_distance,
+            swarms_per_restraint,
+            dense_sampling,
         )
         log.info(f"Generated {len(starting_points_files)} positions files")
     else:
@@ -287,12 +299,12 @@ def create_simulation_info_file(args, path=".", file_name=DEFAULT_LIGHTDOCK_INFO
 
     # Data to store
     now = time.strftime("%Y-%m-%d %H:%M:%S")
-    data = {"start_time": now}
+    data = {"start_time": now, "simulation_version": CURRENT_VERSION}
     data.update(vars(args))
 
     # Store the data in the file sorted alphabetically
     with open(output_file_name, "w") as fp:
-        json.dump(vars(args), fp, indent=4, sort_keys=True)
+        json.dump(data, fp, indent=4, sort_keys=True)
 
     return output_file_name
 
