@@ -5,6 +5,7 @@ import os
 import filecmp
 from pathlib import Path
 from lightdock.test.bin.regression import RegressionTest
+from lightdock.test.support import compare_two_files
 
 
 class TestSetupWithoutRestraints(RegressionTest):
@@ -35,8 +36,9 @@ class TestSetupWithoutRestraints(RegressionTest):
             self.golden_data_path / "init" / "swarm_centers.pdb",
             self.test_path / "init" / "swarm_centers.pdb",
         )
-        assert filecmp.cmp(
-            self.golden_data_path / "setup.json", self.test_path / "setup.json"
+        assert compare_two_files(
+            self.test_path / "setup.json", self.golden_data_path / "setup.json",
+            ignore=["setup_version", "start_time"]
         )
         assert filecmp.cmp(
             self.golden_data_path / "init" / "initial_positions_0.dat",
