@@ -2,7 +2,6 @@
 
 import os
 import shutil
-import filecmp
 from pathlib import Path
 from glob import glob
 from nose.tools import raises
@@ -22,7 +21,9 @@ from lightdock.prep.simulation import (
 )
 from lightdock.structure.complex import Complex
 from lightdock.pdbutil.PDBIO import parse_complex_from_file
-from lightdock.util.parser import SetupCommandLineParser
+from lightdock.util.parser import SetupCommandLineParser, CommandLineParser
+from lightdock.version import CURRENT_VERSION
+from lightdock.test.support import compare_two_files
 
 
 class TestParsingRestraintsFile:
@@ -174,8 +175,12 @@ class TestSimulation:
 
         expected = {
             "anm_lig": 10,
+            "anm_lig_rmsd": 0.5,
             "anm_rec": 10,
+            "anm_rec_rmsd": 0.5,
             "anm_seed": 324324,
+            "dense_sampling": False,
+            "fixed_distance": 0.0,
             "flip": False,
             "glowworms": 10,
             "ligand_pdb": "2UUY_lig.pdb",
@@ -185,10 +190,12 @@ class TestSimulation:
             "noxt": True,
             "receptor_pdb": "2UUY_rec.pdb",
             "restraints": None,
+            "setup_version": CURRENT_VERSION,
             "starting_points_seed": 324324,
             "surface_density": 50.0,
             "swarm_radius": 10.0,
             "swarms": 5,
+            "swarms_per_restraint": 20,
             "transmembrane": False,
             "use_anm": True,
             "verbose_parser": False,
@@ -211,8 +218,9 @@ class TestSimulation:
 
         create_setup_file(parser.args)
 
-        assert filecmp.cmp(
-            self.test_path / "setup.json", self.golden_data_path / "setup.json"
+        assert compare_two_files(
+            self.test_path / "setup.json", self.golden_data_path / "setup.json",
+            ignore=["setup_version", "start_time"]
         )
 
     def test_prepare_results_environment(self):
@@ -340,3 +348,18 @@ class TestSimulation:
 
         glowworms = 9
         assert not check_starting_file(file_name, glowworms, use_anm, anm_rec, anm_lig)
+
+
+    def test_simulation_parser(self):
+        shutil.copyfile(
+            self.golden_data_path / "setup.json", self.test_path / "setup.json"
+        )
+
+        os.chdir(self.test_path)
+        parser = CommandLineParser(
+            ["setup.json", "10", "-c 1", "-l 0", "-s fastdfire"]
+        )
+
+        file_name = create_simulation_info_file(parser.args, path=self.test_path)
+
+        assert Path(file_name).name == "lightdock.info"
