@@ -15,20 +15,20 @@ class TestPyDock:
 
     def test_calculate_PyDock_1AY7(self):
         atoms, _, chains = parse_complex_from_file(
-            self.golden_data_path / "1AY7_rec.pdb.H"
+            self.golden_data_path / "1AY7_rec.pdb"
         )
         receptor = Complex(
             chains,
             atoms,
-            structure_file_name=(self.golden_data_path / "1AY7_rec.pdb.H"),
+            structure_file_name=(self.golden_data_path / "1AY7_rec.pdb"),
         )
         atoms, _, chains = parse_complex_from_file(
-            self.golden_data_path / "1AY7_lig.pdb.H"
+            self.golden_data_path / "1AY7_lig.pdb"
         )
         ligand = Complex(
             chains,
             atoms,
-            structure_file_name=(self.golden_data_path / "1AY7_lig.pdb.H"),
+            structure_file_name=(self.golden_data_path / "1AY7_lig.pdb"),
         )
         adapter = CPyDockAdapter(receptor, ligand)
         assert_almost_equal(
