@@ -16,6 +16,9 @@ from lightdock.constants import (
     DEFAULT_NMODES_LIG,
     DEFAULT_SURFACE_DENSITY,
     DEFAULT_SWARM_RADIUS,
+    DEFAULT_ANM_RMSD,
+    DEFAULT_SWARM_DISTANCE,
+    DEFAULT_SWARMS_PER_RESTRAINT,
 )
 from lightdock.error.lightdock_errors import LightDockError
 from lightdock.version import CURRENT_VERSION
@@ -187,6 +190,25 @@ class SetupCommandLineParser(object):
             type=int,
             default=STARTING_NM_SEED,
         )
+        # ANM RMSD interval for receptor
+        parser.add_argument(
+            "--anm_rec_rmsd",
+            "-anm_rec_rmsd",
+            help="RMSD interval to generate random ANM conformations",
+            dest="anm_rec_rmsd",
+            type=valid_float_number,
+            default=DEFAULT_ANM_RMSD,
+        )
+        # ANM RMSD interval for ligand
+        parser.add_argument(
+            "--anm_lig_rmsd",
+            "-anm_lig_rmsd",
+            help="RMSD interval to generate random ANM conformations",
+            dest="anm_lig_rmsd",
+            type=valid_float_number,
+            default=DEFAULT_ANM_RMSD,
+        )
+        # Default number of non-trivial modes for receptor
         parser.add_argument(
             "-ar",
             "--ar",
@@ -197,6 +219,7 @@ class SetupCommandLineParser(object):
             dest="anm_rec",
             default=DEFAULT_NMODES_REC,
         )
+        # Default number of non-trivial modes for ligand
         parser.add_argument(
             "-al",
             "--al",
@@ -279,6 +302,46 @@ class SetupCommandLineParser(object):
             action="store_true",
             default=False,
         )
+        # Swarm fixed distance
+        parser.add_argument(
+            "-fd",
+            "--fd",
+            "-fixed_distance",
+            "--fixed_distance",
+            help="Use a fixed distance (Å) instead of using ligand to calculate distance of swarms to receptor surface",
+            type=valid_float_number,
+            dest="fixed_distance",
+            default=DEFAULT_SWARM_DISTANCE,
+        )
+        # Number of swarms to keep per restraint
+        parser.add_argument(
+            "-spr",
+            "--spr",
+            "-swarms_per_restraint",
+            "--swarms_per_restraint",
+            help="Number of swarms to keep per restraint",
+            type=valid_natural_number,
+            dest="swarms_per_restraint",
+            default=DEFAULT_SWARMS_PER_RESTRAINT,
+        )
+        # Enable dense sampling
+        parser.add_argument(
+            "--ds",
+            "-ds",
+            help="Enable dense sampling for restraints-swarm filtering",
+            dest="dense_sampling",
+            action="store_true",
+            default=False,
+        )
+        # Version
+        parser.add_argument(
+            "-V",
+            "-v",
+            "--version",
+            help="show version",
+            action="version",
+            version="%s %s" % (parser.prog, CURRENT_VERSION),
+        )
         if input_args:
             self.args = parser.parse_args(input_args)
         else:
@@ -304,7 +367,7 @@ class ListScoringAction(argparse.Action):
 class CommandLineParser(object):
     """Parses the command line"""
 
-    def __init__(self):
+    def __init__(self, input_args=None):
         parser = argparse.ArgumentParser(prog="lightdock3")
 
         # Receptor
@@ -424,5 +487,7 @@ class CommandLineParser(object):
             type=int,
             required=False,
         )
-
-        self.args = parser.parse_args()
+        if input_args:
+            self.args = parser.parse_args(input_args)
+        else:
+            self.args = parser.parse_args()
